python-maec |release| Documentation
====================================

The python-maec library provides an API for developing and consuming Malware
Attribute Enumeration and Characterization (MAEC) content. Developers can 
leverage the API to create applications that create, consume, translate, or 
otherwise work with MAEC content.

Versions
--------
Each version of python-maec is designed to work with a single version of the
MAEC Language.  The table below shows the latest version the library for each
version of MAEC.

============ ===================
MAEC Version python-maec Version
============ ===================
4.1          4.1.0.12 (`PyPI`__) (`GitHub`__)
4.0          4.0.1.0 (`PyPI`__) (`GitHub`__)
3.0          3.0.0b1 (`PyPI`__) (`GitHub`__)
============ ===================

__ https://pypi.python.org/pypi/maec/4.1.0.12
__ https://github.com/MAECProject/python-maec/tree/v4.1.0.12
__ https://pypi.python.org/pypi/maec/4.0.1.0
__ https://github.com/MAECProject/python-maec/tree/v4.0.1.0
__ https://pypi.python.org/pypi/maec/3.0.0b1
__ https://github.com/MAECProject/python-maec/tree/v3.0.0b1


Contents
--------

.. toctree::
   :maxdepth: 2

   getting_started
   installation
   overview
   examples
   api_vs_bindings/index
   contributing
   
API Reference
=============

.. toctree::
   :maxdepth: 1

   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

